![](images/stitchr-logo.png)

### Stitch together TCR coding nucleotide sequences from V/J/CDR3 information

##### Jamie Heather | CCR @ MGH | 2025 

[![tests](https://github.com/JamieHeather/stitchr/actions/workflows/tests.yml/badge.svg)](https://github.com/JamieHeather/stitchr/actions/workflows/tests.yml)
[![PyPI - Version](https://img.shields.io/pypi/v/stitchr)](https://pypi.org/project/stitchr/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/stitchr)](https://pypistats.org/packages/stitchr)
[![DOI](https://img.shields.io/badge/DOI-10.1093%2Fnar%2Fgkac190-blue)](https://doi.org/10.1093/nar/gkac190)
[![License](https://img.shields.io/github/license/JamieHeather/stitchr?label=license)](./LICENSE)

[The documentation for stitchr can be accessed at this link: https://jamieheather.github.io/stitchr/](https://jamieheather.github.io/stitchr/)

